@@ -32,19 +32,15 @@ from numba import vectorize
 
 from tqdm import tqdm
 
-print('Due to some ongoing work on experimental GPU features, some warning statments may print during import')
-print('If you see statements about CUDA or cupy, they should be safe to ignore')
-print('If you have any questions feel free to email me: dgma224@g.uky.edu')
-
 #try to configure the GPU to see if that can be used or not
 __gpuAvailable = False
+__gpuErrorMessage = None
 try:
 	from . import gpuFunctions as gpu
 	__gpuAvailable = True
 except Exception as e:
 	__gpuAvailable = False
-	print("GPU not available to accelerate processing")
-	print(e)
+	__gpuErrorMessage = e
 
 __fxpAvailable = False
 try:
