@@ -111,14 +111,24 @@ def parseFile(filename, headertype):
 	singles, coincidences, pulsers, baselines, cosmics = separateWaveformTypes(file, headertype)
 	if len(singles) > 0:
 		singles = np.asarray(singles)
+	else:
+		singles = None
 	if len(coincidences) > 0:
 		coincidences = np.asarray(coincidences)
+	else:
+		coincidences = None
 	if len(pulsers) > 0:
 		pulsers = np.asarray(pulsers)
+	else:
+		pulsers = None
 	if len(baselines) > 0:
 		baselines = np.asarray(baselines)
+	else:
+		baselines = None
 	if len(cosmics) > 0:
 		cosmics = np.asarray(cosmics)
+	else:
+		cosmics = None
 	del file
 	return singles, coincidences, pulsers, baselines, cosmics
 
@@ -148,11 +158,16 @@ def parseWaveformFiles(directory, run, subrun, headertype):
 	cosmics = []
 	for file in files:
 		s, c, p, b, cos = parseFile(file, headertype)
-		singles.append(s)
-		coincidences.append(c)
-		pulsers.append(p)
-		baselines.append(b)
-		cosmics.append(cos)
+		if s is not None:
+			singles.append(s)
+		if c is not None:
+			coincidences.append(c)
+		if p is not None:
+			pulsers.append(p)
+		if b is not None:
+			baselines.append(b)
+		if cos is not None:
+			cosmics.append(cos)
 	#make singular arrays for each of these
 	singles = np.concatenate(singles)
 	coincidences = np.concatenate(coincidences)
