@@ -223,7 +223,7 @@ class resultFile:
 		width = bin_edges[1]-bin_edges[0]
 		if norm is not None:
 			histogram = histogram / norm
-		plt.plot(bin_edges[:-1], histogram, drawstyle='steps', **kwargs)
+		plt.step(bin_edges[:-1], histogram, where='post', **kwargs)
 		return histogram, bin_edges
 	def fitHist(self, category, bins, function = None, rounding = None, p0=None, bounds=None, parameterNames = None, **kwargs):
 		"""
@@ -294,7 +294,7 @@ class resultFile:
 					else:
 						label+=parameterNames[i]+': '+str(vals[i])+'\n'
 				label=label.strip()
-				plt.plot(bin_edges, function(bin_edges, *popt), label=label, **kwargs)
+				plt.plot(bin_edges+width/2, function(bin_edges+width/2, *popt), label=label, **kwargs)
 				return popt, pcov
 			else:
 				return None, None
